
PyR3.shortcut
=============

This subpackage contains useful abstractions and shortcuts over blender API,
which are used multiple times in other parts of PyR3, but it is mend also
for public access and use.


Manipulating selection and active object
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../examples/shortcut/context/selection.py
   :language: python
   :caption: examples/shortcut/context/selection.py

Using temporary selection
^^^^^^^^^^^^^^^^^^^^^^^^^

.. literalinclude:: ../../examples/shortcut/context/temporary_selection.py
   :language: python
   :caption: examples/shortcut/context/temporary_selection.py

Managing scenes
^^^^^^^^^^^^^^^

.. literalinclude:: ../../examples/shortcut/context/scene.py
   :language: python
   :caption: examples/shortcut/context/scene.py